local _, addonTable = ...
local zc = addonTable.zc
local L = Merchant.Locales.GetString

--------------------------------------------------------------------------------

function Merchant.UI.StockpileGridScrollRefresh(value)
  local frame = Merchant.UI.StockpileGridScrollFrameContent
  local scrollFrameHeight = Merchant.UI.StockpileGridScrollFrame:GetHeight()

  local contentHeight = frame:GetHeight()
  local offset
  if scrollFrameHeight > contentHeight then
    offset = 0
  else
    offset = math.floor((contentHeight - scrollFrameHeight) / 1000.0 * value)
    offset = offset - offset % 35
  end
  frame:ClearAllPoints()
  frame:SetPoint("TOPLEFT", 0, offset)
  frame:SetPoint("TOPRIGHT", 0, offset)

  Merchant.UI.StockpileGridScrollValue = value
end

--------------------------------------------------------------------------------

function Merchant.UI.AddStockpileStock(itemID, count)
  if #Merchant.UI.StockpileStocks < Merchant.UI.StockpileStockCnt then
    local frame = Merchant.UI.StockpileGridScrollFrameContent
    local x = (32 + 10) * ((Merchant.UI.StockpileStockCnt - 1) % Merchant.UI.StockpileGridMaxPerLine)
    local y = (-32 - 10) * math.floor((Merchant.UI.StockpileStockCnt - 1) / Merchant.UI.StockpileGridMaxPerLine)

    local iconFrame = CreateFrame("Frame", nil, frame)
    iconFrame:SetSize(32, 32)
    iconFrame:SetPoint("TOPLEFT", x, y)
    local itemTexture = iconFrame:CreateTexture(nil, "OVERLAY")
    itemTexture:SetAllPoints()

    local countFrame = CreateFrame("Frame", nil, frame)
    countFrame:SetSize(32, 32)
    countFrame:SetPoint("TOPLEFT", x, y - 9)
    local itemCountText = countFrame:CreateFontString(nil, "OVERLAY")
    itemCountText:SetAllPoints()
    itemCountText:SetFont("Fonts\\FRIZQT__.TTF", 11, "THICKOUTLINE")
    itemCountText:SetJustifyH("RIGHT")

    table.insert(Merchant.UI.StockpileStocks, {
      IconFrame = iconFrame,
      ItemTexture = itemTexture,
      ItemCountFrame = countFrame,
      ItemCountText = itemCountText
    })
  end

  local stock = Merchant.UI.StockpileStocks[Merchant.UI.StockpileStockCnt]
  stock.ItemTexture:SetTexture(GetItemIcon(itemID))
  stock.ItemCountText:SetText("|cFFFFFFFF" .. tostring(count))

  Merchant.UI.StockpileStockCnt = Merchant.UI.StockpileStockCnt + 1
  --Merchant.UI.StockpileGridScrollFrameContent:SetHeight((32 + 10) * math.floor((Merchant.UI.StockpileStockCnt - 1) / Merchant.UI.StockpileGridMaxPerLine))
end

--------------------------------------------------------------------------------

function Merchant.UI.EmptyStockpileGrid()
  for key, row in pairs(Merchant.UI.StockpileStocks) do
    row.ItemTexture:SetTexture("")
    row.ItemCountText:SetText("")
  end
  Merchant.UI.StockpileStockCnt = 1
end

--------------------------------------------------------------------------------

function Merchant.UI.DrawStockpileGrid(charName, filter)
  Merchant.UI.EmptyStockpileGrid()
  local stockpile = Merchant_Vars.Accounts[Merchant.RealmName].Stockpile[charName]
  if stockpile == nil then
    Merchant.Debug("error: no stockpile for " .. charName .. " character")
    return
  end
  if filter == "all" then
    table.sort(stockpile, function (a, b) return a.ItemSubClassID < b.ItemSubClassID end)
  end
  for idx, stock in ipairs(stockpile) do
    if filter == "all" or stock.ItemSubClassID == filter then
      Merchant.UI.AddStockpileStock(stock.ItemID, stock.ItemCount)
    end
  end
  if math.floor((Merchant.UI.StockpileStockCnt - 1) / Merchant.UI.StockpileGridMaxPerLine) > 9 then
    Merchant.UI.StockpileGridScrollFrameSlider:Show()
  else
    Merchant.UI.StockpileGridScrollFrameSlider:Hide()
  end
end
